---
feature_story: FS_74_69_61_79
feature_title: get set data envelope
feature_status: TODO
---

Currently, the data is populated by plugins running inside the server process during start-up.

There should be a way to update data out of the server process, to get/set envelope:
*   CLI command
*   REST API call

# See also

Original issue: https://github.com/argrelay/argrelay/issues/20
